@@ -548,6 +548,9 @@ class PinholeCameraModel(object):
     def from_yaml_file(filename):
         """Create instance of PinholeCameraModel from yaml file.
 
+        This function is supporting OpenCV calibration program's
+        YAML format and sensor_msgs/CameraInfo's YAML format in ROS.
+
         Parameters
         ----------
         filename : str
@@ -560,20 +563,35 @@ class PinholeCameraModel(object):
         """
         with open(filename, 'r') as f:
             data = yaml.load(f, Loader=yaml.FullLoader)
-        image_width = data['image_width']
-        image_height = data['image_height']
-        K = data['camera_matrix']['data']
-        P = data['projection_matrix']['data']
-        R = data['rectification_matrix']['data']
-        D = data['distortion_coefficients']['data']
-        if 'camera_name' in data:
-            name = data['camera_name']
-        else:
+        if 'image_width' in data:
+            # opencv format
+            image_width = data['image_width']
+            image_height = data['image_height']
+            K = data['camera_matrix']['data']
+            P = data['projection_matrix']['data']
+            R = data['rectification_matrix']['data']
+            D = data['distortion_coefficients']['data']
+            distortion_model = 'plumb_bob'
+            if 'camera_name' in data:
+                name = data['camera_name']
+            else:
+                name = ''
+        elif 'width' in data:
+            # ROS yaml format
+            image_width = data['width']
+            image_height = data['height']
+            K = data['K']
+            P = data['P']
+            R = data['R']
+            D = data['D']
+            distortion_model = data['distortion_model']
             name = ''
+        else:
+            raise RuntimeError("Not supported YAML file.")
         return PinholeCameraModel(
             image_height, image_width,
             K, P, R, D,
-            distortion_model=data['distortion_model'],
+            distortion_model=distortion_model,
             name=name)
 
     @staticmethod
@@ -815,6 +833,65 @@ class PinholeCameraModel(object):
             translation.reshape(3, 1), (1, view_frust_pts.shape[1]))
         return view_frust_pts.T
 
+    def flatten_uv(self, uv, dtype=np.int64):
+        """Flattens uv coordinates to single dimensional tensor.
+
+        This is the inverse of :meth:`flattened_pixel_locations_to_uv`.
+
+        Parameters
+        ----------
+        uv : numpy.ndarray or list[tuple(float, float)]
+            A pair of uv pixels. Shape of (batch_size, 2).
+            [(u_1, v_1), (u_2, v_2) ..., (u_n, v_n)].
+        dtype : type
+            data type. default is numpy.int64.
+
+        Returns
+        -------
+        ret : numpy.ndarray
+            Flattened uv tensor of shape (n, ).
+
+        Examples
+        --------
+        >>> from cameramodels import PinholeCameraModel
+        >>> cm = PinholeCameraModel.from_fovy(45, 480, 640)
+        >>> cm.flatten_uv(np.array([(1, 0), (100, 1), (100, 2)]))
+        array([   1,  740, 1380])
+        """
+        uv = np.array(uv)
+        return np.array(uv[:, 1], dtype=dtype) * self.width \
+            + np.array(uv[:, 0], dtype=dtype)
+
+    def flattened_pixel_locations_to_uv(self, flat_pixel_locations):
+        """Flattens pixel locations(single dimension tensor) to uv coordinates.
+
+        This is the inverse of :meth:`flatten_uv`.
+
+        Parameters
+        ----------
+        flat_pixel_locations : numpy.ndarray or list[float]
+            Flattened pixel locations.
+
+        Returns
+        -------
+        ret : numpy.ndarray
+            UV coordinates.
+
+        Examples
+        --------
+        >>> from cameramodels import PinholeCameraModel
+        >>> cm = PinholeCameraModel.from_fovy(45, 480, 640)
+        >>> flatten_uv = [1, 740, 1380]
+        >>> cm.flattened_pixel_locations_to_uv(flatten_uv)
+        array([[  1,   0],
+               [100,   1],
+               [100,   2]])
+        """
+        flat_pixel_locations = np.array(flat_pixel_locations, dtype=np.int64)
+        return np.hstack([
+            (flat_pixel_locations % self.width).reshape(-1, 1),
+            (flat_pixel_locations.T // self.width).reshape(-1, 1)])
+
     def dump(self, output_filepath):
         """Dump this camera's parameter to yaml file.
 
