@@ -1,3 +1,4 @@
+import os.path as osp
 import unittest
 
 import numpy as np
@@ -6,6 +7,11 @@ from numpy import testing
 from cameramodels import PinholeCameraModel
 
 
+data_dir = osp.join(osp.abspath(osp.dirname(__file__)), 'data')
+camera_info_path = osp.join(data_dir, 'camera_info.yaml')
+ros_camera_info_path = osp.join(data_dir, 'ros_camera_info.yaml')
+
+
 class TestPinholeCameraModel(unittest.TestCase):
 
     cm = None
@@ -53,3 +59,18 @@ class TestPinholeCameraModel(unittest.TestCase):
             project_valid_depth_only=True,
             return_indices=True)
         testing.assert_equal(valid_indices, np.array([1]))
+
+    def test_flatten_uv(self):
+        cm = self.cm
+        flatten_uv = cm.flatten_uv(np.array([(1, 0), (100, 1), (100, 2)]))
+        testing.assert_equal(flatten_uv, [1, 740, 1380])
+
+    def test_flattened_pixel_locations_to_uv(self):
+        cm = self.cm
+        flatten_uv = [1, 740, 1380]
+        uv = cm.flattened_pixel_locations_to_uv(flatten_uv)
+        testing.assert_equal(uv, [(1, 0), (100, 1), (100, 2)])
+
+    def test_from_yaml_file(self):
+        PinholeCameraModel.from_yaml_file(camera_info_path)
+        PinholeCameraModel.from_yaml_file(ros_camera_info_path)
